doapfiend.plugins.xml.OutputPlugin

Package doapfiend :: Package plugins :: Module xml :: Class OutputPlugin |
[hide private]
[frames] | no frames]

# Class OutputPlugin

source code

     object --+
              |
    base.Plugin --+
                  |
                 OutputPlugin

Class for formatting DOAP output

Instance Methods | [hide private]
__init__(self) Setup RDF/XML OutputPlugin class | source code
add_options(self, parser, output, search) Add plugin's options to doapfiend's opt parser | source code
unicode |
serialize(self, doap_xml, color=False) Serialize RDF/XML DOAP as N3 syntax | source code
Inherited from `base.Plugin`: `configure`, `help` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables | [hide private]
| name = ``'``xml``'``
| enabled = `False`
| enable_opt = `None`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self) (Constructor) | source code
Setup RDF/XML OutputPlugin class Overrides: object.__init__

### add_options(self, parser, output, search) | source code
Add plugin's options to doapfiend's opt parser Overrides: base.Plugin.add_options

### serialize(self, doap_xml, color=False) | source code
Serialize RDF/XML DOAP as N3 syntax Since the only input we currently have is XML, all this really does is parse the XML and raise an exception if it's invalid. When we do content negotiation/accept N3 etc., this will serialize. Parameters: `doap_xml` (string) - DOAP in RDF/XML serialization Returns: unicode DOAP